%define major		6
%define libname		%mklibname %{name} %{major}

%define libplus_major	3
%define libplus		%mklibname mlt++ %{libplus_major}

%define libnamedev	%mklibname %{name} -d

Name:		mlt
Version:	6.16.0
Release:	%mkrel 1
Summary:	Media Lovin' Toolkit
License:	LGPLv2+ and GPLv2+
Group:		Video/Editors and Converters
Url:		https://www.mltframework.org
Source0:	https://github.com/mltframework/mlt/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:	ffmpeg-devel
BuildRequires:	imagemagick
BuildRequires:	ladspa-devel
BuildRequires:	multiarch-utils >= 1.0.3
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(frei0r)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(libdv)
BuildRequires:	pkgconfig(libexif)
BuildRequires:	pkgconfig(libquicktime)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(mad)
BuildRequires:	pkgconfig(movit)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(pango)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(sox)
BuildRequires:	pkgconfig(vidstab)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	qtbase5-common-devel
# For python-bindings
BuildRequires:	swig
BuildRequires:	pkgconfig(python2)

%description
MLT is an open source multimedia framework, designed and developed for
television broadcasting.

It provides a toolkit for broadcasters, video editors, media players,
transcoders, web streamers and many more types of applications. The
functionality of the system is provided via an assortment of ready to
use tools, xml authoring components, and an extendible plug-in based
API.

%package kdenlive
Summary:	Media Lovin' Toolkit
Group:		Video/Editors and Converters
Conflicts:	%{name} < 0.8.8-2

%description kdenlive
MLT is an open source multimedia framework, designed and developed for
television broadcasting.

It provides a toolkit for broadcasters, video editors, media players,
transcoders, web streamers and many more types of applications. The
functionality of the system is provided via an assortment of ready to
use tools, xml authoring components, and an extendible plug-in based
API.

This package contains plugins aimed to be used by kde apps.

%package -n %{libname}
Summary:	Main library for mlt
Group:		System/Libraries

%description -n %{libname}
This package contains the libraries needed to run programs dynamically
linked with mlt.

%package -n %{libplus}
Summary:	Main library for mlt++
Group:		System/Libraries

%description -n %{libplus}
This package contains the libraries needed to run programs dynamically
linked with mlt++.

%package -n %{libnamedev}
Summary:	Headers for developing programs that will use mlt
Group:		Development/C
Requires:	%{libname} = %{version}
Requires:	%{libplus} = %{version}
# mlt-config requires stuff from %%{_datadir}/%%{name}
Requires:	%{name} = %{version}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{libnamedev}
This package contains the headers that programmers will need to develop
applications which will use mlt.

%package -n python2-%{name}
Summary:	Python 2 bindings for MLT
Group:		Development/Python
Requires:	python2
Requires:	%{name} = %{version}-%{release}

Obsoletes:	python-mlt < 6.6.0-4
Provides:	python-mlt = %{version}-%{release}

%description -n python2-%{name}
This module allows to work with MLT using python 2.

%prep
%autosetup -p1

%build
# (akien) Needed to include Qt5, at least on mga6
export CXXFLAGS="-std=c++11"

%configure2_5x \
	--disable-debug \
	--enable-gpl \
	--enable-gpl3 \
%ifnarch %{ix86} x86_64
	--disable-mmx \
%endif
%ifnarch x86_64
	--disable-sse2 \
%endif
	--luma-compress \
	--enable-avformat \
	--avformat-shared=%{_prefix} \
	--avformat-swscale \
	--enable-motion-est \
	--swig-languages='python' \
	--qimage-includedir=%{_qt5_includedir} --qimage-libdir=%{_qt5_libdir} \
	--qt-includedir=%{_qt5_includedir} --qt-libdir=%{_qt5_libdir}
%make_build

%install
%make_install

#man page
install -Dpm644 docs/melt.1 %{buildroot}%{_mandir}/man1/melt.1

#python bindings
install -d %{buildroot}%{python2_sitearch}
install -pm 0644 src/swig/python/%{name}.py* %{buildroot}%{python2_sitearch}/
install -pm 0755 src/swig/python/_%{name}.so %{buildroot}%{python2_sitearch}/

%files
%doc docs/*.txt README
%license COPYING
%{_bindir}/melt
%{_datadir}/mlt
%{_libdir}/mlt/
%{_mandir}/man1/melt.1*
%exclude %{_libdir}/mlt/libmltkdenlive.so

%files kdenlive
%{_libdir}/mlt/libmltkdenlive.so

%files -n %{libname}
%{_libdir}/libmlt.so.%{major}{,.*}
%{_libdir}/libmlt.so.%{version}

%files -n %{libplus}
%{_libdir}/libmlt++.so.%{libplus_major}{,.*}
%{_libdir}/libmlt++.so.%{version}

%files -n %{libnamedev}
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files -n python2-%{name}
%{python2_sitearch}/%{name}.p*
%{python2_sitearch}/_%{name}.so


%changelog
* Wed Oct 02 2019 akien <akien> 6.16.0-1.mga7
+ Revision: 1448846
- Version 6.16.0, updated for latest shotcut

* Wed Apr 10 2019 zezinho <zezinho> 6.14.0-1.mga7
+ Revision: 1387938
- new version 6.14

* Sun Mar 31 2019 umeabot <umeabot> 6.12.0-2.mga7
+ Revision: 1383459
- Qt5 Rebuild

* Thu Dec 13 2018 zezinho <zezinho> 6.12.0-1.mga7
+ Revision: 1341097
- new version 6.12.0

* Sat Aug 25 2018 zezinho <zezinho> 6.10.0-1.mga7
+ Revision: 1254404
- new version 6.10.0

* Mon May 28 2018 akien <akien> 6.8.0-1.mga7
+ Revision: 1232769
- Version 6.8.0

* Mon Apr 23 2018 zezinho <zezinho> 6.6.0-5.mga7
+ Revision: 1221700
- rebuild against ffmpeg 4

* Mon Feb 26 2018 daviddavid <daviddavid> 6.6.0-4.mga7
+ Revision: 1205367
- fix version of obsoleted python-mlt

* Mon Feb 26 2018 daviddavid <daviddavid> 6.6.0-3.mga7
+ Revision: 1205298
- rebuild for new movit
- rename python-mlt to python2-mlt

* Thu Feb 01 2018 zezinho <zezinho> 6.6.0-2.mga7
+ Revision: 1198513
- enable MMX and SSE1 in x86

* Thu Feb 01 2018 zezinho <zezinho> 6.6.0-1.mga7
+ Revision: 1198477
- new version

* Thu Aug 24 2017 ovitters <ovitters> 6.4.1-3.mga7
+ Revision: 1145167
+ rebuild (emptylog)

* Tue May 02 2017 akien <akien> 6.4.1-3.mga6
+ Revision: 1098310
- Rebuild for ffmpeg 3.3

* Sat Jan 21 2017 zezinho <zezinho> 6.4.1-2.mga6
+ Revision: 1082861
- enable Movit Gpu Effects

* Sat Jan 21 2017 zezinho <zezinho> 6.4.1-1.mga6
+ Revision: 1082702
- new version 6.4.1

* Tue May 10 2016 zezinho <zezinho> 6.2.0-1.mga6
+ Revision: 1012358
- new version 6.2.0

* Mon Feb 15 2016 umeabot <umeabot> 0.9.8-8.mga6
+ Revision: 961463
- Mageia 6 Mass Rebuild

* Fri Sep 11 2015 daviddavid <daviddavid> 0.9.8-7.mga6
+ Revision: 876945
- rebuild for new sox 14.4.2

* Mon Sep 07 2015 sander85 <sander85> 0.9.8-6.mga6
+ Revision: 873947
- Bring back qimage

* Tue Aug 25 2015 sander85 <sander85> 0.9.8-5.mga6
+ Revision: 869306
- Build with Qt5

* Fri Jul 31 2015 wally <wally> 0.9.8-4.mga6
+ Revision: 860099
- install man page
- use %%license for COPYING

* Fri Jul 31 2015 wally <wally> 0.9.8-3.mga6
+ Revision: 860053
- BR fftw-devel

* Fri Jul 31 2015 wally <wally> 0.9.8-2.mga6
+ Revision: 860047
- enable GPLv3 components

* Fri Jul 31 2015 wally <wally> 0.9.8-1.mga6
+ Revision: 859948
- new version 0.9.8
- update URL
+ akien <akien>
- Rebuild for ffmpeg 2.4

* Wed Oct 15 2014 umeabot <umeabot> 0.9.2-4.mga5
+ Revision: 748641
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.9.2-3.mga5
+ Revision: 727337
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.9.2-2.mga5
+ Revision: 682547
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 juancho <juancho> 0.9.2-1.mga5
+ Revision: 670322
- Updated to version 0.9.2

* Sun Jul 06 2014 fwang <fwang> 0.9.0-3.mga5
+ Revision: 644179
- fix build with recent freetype
+ pterjan <pterjan>
- Rebuild for new Python

* Sat Oct 19 2013 umeabot <umeabot> 0.9.0-2.mga4
+ Revision: 529702
- Mageia 4 Mass Rebuild

* Thu Jul 11 2013 fwang <fwang> 0.9.0-1.mga4
+ Revision: 452914
- bump libmajor
- new version 0.9.0

* Mon Feb 04 2013 fwang <fwang> 0.8.8-3.mga3
+ Revision: 394478
- add conflicts to ease upgrading

* Mon Feb 04 2013 neoclust <neoclust> 0.8.8-2.mga3
+ Revision: 394470
- Try to remove kde deps out of main package

* Wed Jan 30 2013 zezinho <zezinho> 0.8.8-1.mga3
+ Revision: 393528
- new version

* Tue Jan 29 2013 cjw <cjw> 0.8.6-4.mga3
+ Revision: 393221
- patch1 from mlt git: fix audio decoding with ffmpeg 1.1

* Sat Jan 12 2013 umeabot <umeabot> 0.8.6-3.mga3
+ Revision: 360171
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 0.8.6-2.mga3
+ Revision: 341726
- rebuild for new ffmpeg

* Thu Nov 29 2012 juancho <juancho> 0.8.6-1.mga3
+ Revision: 322924
- Updated group to comply with new RPM group policy.
- Updated to 0.8.6

* Wed Sep 12 2012 fwang <fwang> 0.8.2-1.mga3
+ Revision: 292515
- new version 0.8.2

* Mon Jul 30 2012 fwang <fwang> 0.8.0-2.mga3
+ Revision: 275947
- rebuild for new sox

* Fri Jun 15 2012 fwang <fwang> 0.8.0-1.mga3
+ Revision: 260700
- update libamjor
- new version 0.8.0

* Wed May 30 2012 fwang <fwang> 0.7.8-3.mga3
+ Revision: 249674
- rebuild for new ffmpeg

* Sun Apr 08 2012 sander85 <sander85> 0.7.8-2.mga2
+ Revision: 229720
- fix some audio codecs not detected with newer libavcodec

* Mon Feb 27 2012 fwang <fwang> 0.7.8-1.mga2
+ Revision: 215634
- drop more internal sybol
- new version 0.7.8

* Tue Dec 27 2011 dmorgan <dmorgan> 0.7.6-2.mga2
+ Revision: 188252
- Do not use ffmeg private symbols ( mga #3732)

* Tue Nov 01 2011 fwang <fwang> 0.7.6-1.mga2
+ Revision: 160763
- new version 0.7.6
- new version 0.7.4

* Mon Jul 04 2011 ahmad <ahmad> 0.7.2-3.mga2
+ Revision: 118265
- Add BR frei0r-devel

* Sat Jun 25 2011 fwang <fwang> 0.7.2-2.mga2
+ Revision: 113451
- rebuild for new ffmpeg

* Tue May 17 2011 dmorgan <dmorgan> 0.7.2-1.mga1
+ Revision: 99445
- New version 0.7.2

* Thu Feb 17 2011 wally <wally> 0.6.2-1.mga1
+ Revision: 53196
- new version 0.6.2
- new major 3
- fix license and summary
- drop old obsoletes
- clean .spec
- imported package mlt

